@@ -25,31 +25,47 @@
 
 #define __GIO_GIO_H_INSIDE__
 
-#include <gio/gvfs.h>
-#include <gio/gfile.h>
-#include <gio/gvolumemonitor.h>
-#include <gio/gcontenttype.h>
+#include <gio/giotypes.h>
+
 #include <gio/gappinfo.h>
-#include <gio/gicon.h>
-#include <gio/gfileicon.h>
-#include <gio/gloadableicon.h>
-#include <gio/gthemedicon.h>
-#include <gio/gseekable.h>
-#include <gio/gfilemonitor.h>
+#include <gio/gasyncresult.h>
 #include <gio/gbufferedinputstream.h>
 #include <gio/gbufferedoutputstream.h>
+#include <gio/gcancellable.h>
+#include <gio/gcontenttype.h>
 #include <gio/gdatainputstream.h>
 #include <gio/gdataoutputstream.h>
+#include <gio/gdrive.h>
+#include <gio/gfile.h>
+#include <gio/gfileattribute.h>
+#include <gio/gfileenumerator.h>
+#include <gio/gfileicon.h>
+#include <gio/gfileinfo.h>
+#include <gio/gfileinputstream.h>
+#include <gio/gfilemonitor.h>
 #include <gio/gfilenamecompleter.h>
+#include <gio/gfileoutputstream.h>
 #include <gio/gfilterinputstream.h>
 #include <gio/gfilteroutputstream.h>
+#include <gio/gicon.h>
+#include <gio/ginputstream.h>
+#include <gio/gioenumtypes.h>
+#include <gio/gioerror.h>
 #include <gio/giomodule.h>
 #include <gio/gioscheduler.h>
+#include <gio/gloadableicon.h>
 #include <gio/gmemoryinputstream.h>
 #include <gio/gmemoryoutputstream.h>
-#include <gio/gsimpleasyncresult.h>
-#include <gio/gioenumtypes.h>
+#include <gio/gmount.h>
+#include <gio/gmountoperation.h>
 #include <gio/gnativevolumemonitor.h>
+#include <gio/goutputstream.h>
+#include <gio/gseekable.h>
+#include <gio/gsimpleasyncresult.h>
+#include <gio/gthemedicon.h>
+#include <gio/gvfs.h>
+#include <gio/gvolume.h>
+#include <gio/gvolumemonitor.h>
 
 #undef __GIO_GIO_H_INSIDE__
 
