@@ -205,8 +205,9 @@ g_option_error_quark (void)
  * program functionality that should be displayed as a paragraph
  * below the usage line, use g_option_context_set_summary().
  *
- * Note that the @parameter_string is translated (see
- * g_option_context_set_translate_func()). 
+ * Note that the @parameter_string is translated using the
+ * function set with g_option_context_set_translate_func(), so
+ * it should normally be passed untranslated.
  *
  * Returns: a newly created #GOptionContext, which must be
  *    freed with g_option_context_free() after use.
@@ -519,6 +520,48 @@ print_entry (GOptionGroup       *group,
   g_string_free (str, TRUE);  
 }
 
+static gboolean
+group_has_visible_entries (GOptionContext *context,
+                           GOptionGroup *group,
+                           gboolean      main_entries)
+{
+  GOptionFlags reject_filter = G_OPTION_FLAG_HIDDEN;
+  GOptionEntry *entry;
+  gint i, l;
+  gboolean main_group = group == context->main_group;
+
+  if (!main_entries)
+    reject_filter |= G_OPTION_FLAG_IN_MAIN;
+
+  for (i = 0, l = (group ? group->n_entries : 0); i < l; i++)
+    {
+      entry = &group->entries[i];
+
+      if (main_entries && !main_group && !(entry->flags & G_OPTION_FLAG_IN_MAIN))
+        continue;
+      if (!(entry->flags & reject_filter))
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
+static gboolean
+group_list_has_visible_entires (GOptionContext *context,
+                                GList          *group_list,
+                                gboolean       main_entries)
+{
+  while (group_list)
+    {
+      if (group_has_visible_entries (context, group_list->data, main_entries))
+        return TRUE;
+
+      group_list = group_list->next;
+    }
+
+  return FALSE;
+}
+
 /**
  * g_option_context_get_help: 
  * @context: a #GOptionContext
@@ -573,14 +616,14 @@ g_option_context_get_help (GOptionContext *context,
 
   if (rest_description)
     {
-      g_string_printf (string, " ");
-      g_string_printf (string, rest_description);
+      g_string_append (string, " ");
+      g_string_append (string, rest_description);
     }
 
   if (context->parameter_string)
     {
-      g_string_printf (string, " ");
-      g_string_printf (string, TRANSLATE (context, context->parameter_string));
+      g_string_append (string, " ");
+      g_string_append (string, TRANSLATE (context, context->parameter_string));
     }
 
   g_string_append (string, "\n\n");
@@ -685,10 +728,11 @@ g_option_context_get_help (GOptionContext *context,
       while (list)
 	{
 	  GOptionGroup *group = list->data;
-	  
-	  g_string_append_printf (string, "  --help-%-*s %s\n", 
-                                  max_length - 5, group->name, 
-		                  TRANSLATE (group, group->help_description));
+
+	  if (group_has_visible_entries (context, group, FALSE))
+	    g_string_append_printf (string, "  --help-%-*s %s\n",
+				    max_length - 5, group->name,
+				    TRANSLATE (group, group->help_description));
 	  
 	  list = list->next;
 	}
@@ -699,12 +743,15 @@ g_option_context_get_help (GOptionContext *context,
   if (group)
     {
       /* Print a certain group */
-      
-      g_string_append (string, TRANSLATE (group, group->description));
-      g_string_append (string, "\n");
-      for (i = 0; i < group->n_entries; i++)
-	print_entry (group, max_length, &group->entries[i], string);
-      g_string_append (string, "\n");
+
+      if (group_has_visible_entries (context, group, FALSE))
+        {
+          g_string_append (string, TRANSLATE (group, group->description));
+          g_string_append (string, "\n");
+          for (i = 0; i < group->n_entries; i++)
+            print_entry (group, max_length, &group->entries[i], string);
+          g_string_append (string, "\n");
+        }
     }
   else if (!main_help)
     {
@@ -716,19 +763,25 @@ g_option_context_get_help (GOptionContext *context,
 	{
 	  GOptionGroup *group = list->data;
 
-	  g_string_append (string, group->description);
-          g_string_append (string, "\n");
-	  for (i = 0; i < group->n_entries; i++)
-	    if (!(group->entries[i].flags & G_OPTION_FLAG_IN_MAIN))
-	      print_entry (group, max_length, &group->entries[i], string);
+	  if (group_has_visible_entries (context, group, FALSE))
+	    {
+	      g_string_append (string, group->description);
+	      g_string_append (string, "\n");
+	      for (i = 0; i < group->n_entries; i++)
+		if (!(group->entries[i].flags & G_OPTION_FLAG_IN_MAIN))
+		  print_entry (group, max_length, &group->entries[i], string);
 	  
-	  g_string_append (string, "\n");
+	      g_string_append (string, "\n");
+	    }
+
 	  list = list->next;
 	}
     }
   
   /* Print application options if --help or --help-all has been specified */
-  if (main_help || !group)
+  if ((main_help || !group) &&
+      (group_has_visible_entries (context, context->main_group, TRUE) ||
+       group_list_has_visible_entires (context, context->groups, TRUE)))
     {
       list = context->groups;
 
@@ -771,7 +824,7 @@ print_help (GOptionContext *context,
   gchar *help;
 
   help = g_option_context_get_help (context, main_help, group);
-  g_printf (help);
+  g_print ("%s", help);
   g_free (help);
 
   exit (0);  
@@ -2001,11 +2054,11 @@ g_option_group_set_translate_func (GOptionGroup   *group,
   group->translate_notify = destroy_notify;
 }
 
-static gchar *
+static const gchar *
 dgettext_swapped (const gchar *msgid, 
 		  const gchar *domainname)
 {
-  return dgettext (domainname, msgid);
+  return g_dgettext (domainname, msgid);
 }
 
 /**
